==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/OnClosedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnClosedEventArgsDescription } from "./OnClosedEventArgsDescription";
/**
 * @hidden
 */
export let OnClosedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OnClosedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OnClosedEventArgsDescriptionMetadata.a == null) {
                OnClosedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OnClosedEventArgsDescriptionMetadata.c(OnClosedEventArgsDescriptionMetadata.a);
            }
            if (a.j(OnClosedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(OnClosedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OnClosedEventArgsDescriptionMetadata.b(a);
            a.aa("OnClosedEventArgs", () => new OnClosedEventArgsDescription());
            a.z("OnClosedEventArgs", OnClosedEventArgsDescriptionMetadata.a);
        }
    }
    OnClosedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(OnClosedEventArgsDescriptionMetadata, 'OnClosedEventArgsDescriptionMetadata');
    OnClosedEventArgsDescriptionMetadata.a = null;
    return OnClosedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/OnClosedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OnClosedEventArgsDescription } from "./OnClosedEventArgsDescription";
/**
 * @hidden
 */
export let OnClosedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class OnClosedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (OnClosedEventArgsDescriptionMetadata.a == null) {
                OnClosedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                OnClosedEventArgsDescriptionMetadata.c(OnClosedEventArgsDescriptionMetadata.a);
            }
            if (a.k(OnClosedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(OnClosedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            OnClosedEventArgsDescriptionMetadata.b(a);
            a.ac("OnClosedEventArgs", () => new OnClosedEventArgsDescription());
            a.ab("OnClosedEventArgs", OnClosedEventArgsDescriptionMetadata.a);
        }
    }
    OnClosedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(OnClosedEventArgsDescriptionMetadata, 'OnClosedEventArgsDescriptionMetadata');
    OnClosedEventArgsDescriptionMetadata.a = null;
    return OnClosedEventArgsDescriptionMetadata;
})();
